==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/tr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Herkese açık bağlantı",
    "Photos" : "Fotoğraflar",
    "On This Day" : "Şu günde",
    "Your memories under your control" : "Anılarınızın denetimi sizde",
    "All media" : "Tüm ortamlar",
    "Videos" : "Görüntüler",
    "Albums" : "Albümler",
    "Collaborative albums" : "İş birlikli albümler",
    "People" : "Kişiler",
    "Folders" : "Klasörler",
    "Favorites" : "Sık kullanılanlar",
    "On this day" : "Bugün",
    "Shared with you" : "Sizinle paylaşılanlar",
    "Tags" : "Etiketler",
    "Places" : "Yerler",
    "Map" : "Harita",
    "Photos settings" : "Fotoğraflar ayarları",
    "Mark selection as favorite" : "Seçilmişleri sık kullanılanlara ekle",
    "Add selection to favorites" : "Seçilmişleri sık kullanılanlara ekle",
    "Remove selection from favorites" : "Seçilmişleri sık kullanılanlardan çıkar",
    "Name of the album" : "Albümün adı",
    "Location of the album" : "Albümün konumu",
    "Back" : "Geri",
    "Add collaborators" : "Katılımcı ekle",
    "Save" : "Kaydet",
    "Create album" : "Albüm ekle",
    "Add to Album" : "Albüme ekle",
    "Add selection to album {albumName}" : "Seçilmişleri {albumName} albümüne ekle",
    "Shared by" : "Paylaşan",
    "Create a new album." : "Yeni bir albüm ekler.",
    "Create new album" : "Yeni albüm ekle",
    "New album" : "Yeni albüm",
    "_%n item_::_%n photos and videos_" : ["%n öge","%n fotoğraf ve görüntü"],
    "Failed to fetch collaborators list." : "Katılımcıların listesi alınamadı.",
    "Failed to update album." : "Albüm güncellenemedi",
    "Add people or groups who can edit your album" : "Albümünüzü düzenleyebilecek kişi ya da grupları ekleyin",
    "Search people or groups" : "Kişi ya da grup arama",
    "No recommendations. Start typing." : "Herhangi bir öneri yok. Yazmaya başlayın.",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
    "Copy the public link" : "Herkese açık bağlantıyı kopyala",
    "Public link copied!" : "Herkese açık bağlantı kopyalandı!",
    "Copy public link" : "Herkese açık bağlantıyı kopyala",
    "Delete the public link" : "Herkese açık bağlantıyı sil",
    "Create public link share" : "Herkese açık paylaşılan bağlantı oluştur",
    "Share via public link" : "Herkese açık bağlantı ile paylaş",
    "This collection does not exist" : "Derleme bulunamadı",
    "An error occurred" : "Bir sorun çıktı",
    "No picture for this day" : "Bu günde çekilmiş bir fotoğraf yok",
    "Picture taken on this day will show up here." : "Bu gün çekilmiş fotoğraflar burada görüntülenir.",
    "More photos from this day" : "Bu gün çekilmiş diğer fotoğraflar",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ilişkilendirilmemiş fotoğraf","%n ilişkilendirilmemiş fotoğraf"],
    "Favorite" : "Sık kullanılanlara ekle",
    "Favorite image, open the full size \"{name}\" image" : "Görseli öne çıkar, \"{name}\" görselini tam boyutunda aç",
    "Open the full size \"{name}\" image" : "\"{name}\" görselini tam boyutunda aç",
    "Select image {imageName}" : "{imageName} görselini seç",
    "Open the \"{name}\" folder" : "\"{name}\" klasörünü aç",
    "Back to {folder}" : "{folder} klasörüne geri dön",
    "Go back" : "Geri dön",
    "Share this folder" : "Bu klasörü paylaş",
    "Dates" : "Tarihler",
    "Jump to specific date in list" : "Listede belirli bir tarihe git",
    "Jump to {date}" : "{date} tarihine git",
    "Add to {destination}" : "{destination} üzerine ekle",
    "The destination folder is owned by {owner}" : "Hedef klasörün sahibi {owner}",
    "There are no photos or videos yet!" : "Henüz bir fotoğraf ya da görüntü yok!",
    "_{years} year ago_::_{years} years ago_" : ["{years} yıl önce","{years} yıl önce"],
    "Enable squared photos view" : "Kare fotoğraf görünümü kullanılsın",
    "Delete source directory" : "Kaynak klasörü sil",
    "Pick folder" : "Klasör seçin",
    "Select a source folder for your media" : "Ortamlarınız için bir kaynak klasör seçin",
    "All folders" : "Tüm klasörler",
    "Add a Photos source for the timelines" : "Zaman akışları için bir fotoğraf kaynağı ekleyin",
    "Add folder" : "Klasör ekle",
    "Select the default upload location for your media" : "Ortamlarınız için varsayılan yükleme konumunu seçin",
    "Home" : "Giriş",
    "Choose default Photos upload and Albums location" : "Varsayılan Fotoğraflar yüklemesini ve Albümlerin konumu seçin",
    "Choose a different folder" : "Farklı bir klasör seçin",
    "View" : "Görüntüle",
    "Media folders" : "Ortam klasörleri",
    "Choose the folders from where photos and videos are shown." : "Fotoğraf ve videoların görüntüleneceği klasörleri seçin.",
    "Upload folder" : "Yükleme klasörü",
    "Choose the folder where photos and albums are uploaded to." : "Fotoğraf ve albümlerin yükleneceği klasörü seçin.",
    "_%n photo_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "Unselect all" : "Tümünü bırak",
    "Add photos to this album" : "Bu albüme fotoğraflar ekle",
    "Manage collaborators for this album" : "Bu albümün katılımcılarını yönet",
    "Open actions menu" : "İşlemler menüsünü aç",
    "Edit album details" : "Albüm ayrıntılarını düzenle",
    "Download all files in album" : "Albümdeki tüm dosyaları indir",
    "Delete album" : "Albümü sil",
    "Download selected files" : "Seçilmiş dosyaları indir",
    "Remove selection from album" : "Seçilmişleri albümden kaldır",
    "This album does not have any photos or videos yet!" : "Bu albümde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to {albumName}" : "{albumName} albümüne fotoğraflar ekle",
    "Manage collaborators" : "Katılımcı yönetimi",
    "Save collaborators for this album." : "Bu albümün katılımcılarını kaydet.",
    "Cover photo for album {albumName}" : "{albumName} albümünün kapak görseli",
    "There is no album yet!" : "Henüz bir albüm yok!",
    "This person could not be found" : "Bu kişi bulunamadı",
    "Rename person" : "Kişiyi yeniden adlandır",
    "Merge with different person" : "Başka bir kişi ile birleştir",
    "Download selected photos" : "Seçilmiş fotoğrafları indir",
    "Remove from favorites" : "Sık kullanılanlardan çıkar",
    "Remove person" : "Kişiyi sil",
    "Name of this person" : "Bu kişinin adı",
    "Save." : "Kaydeder.",
    "Merge person" : "Kişiyi birleştir",
    "Move to different person" : "Farklı bir kişiye aktar",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Fotoğrafı başka bir kişiye aktar","Fotoğrafları başka bir kişiye aktar"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fotoğrafı kişiden kaldır","Fotoğrafları kişiden kaldır"],
    "This might take some time depending on the size of your photo library." : "Bu işlemin tamamlanması fotoğraf arşivinizin boyutuna bağlı olarak biraz zaman alabilir.",
    "Recognized people will show up here" : "Tanınan kişiler burada görüntülenir",
    "This folder does not exist" : "Bu klasör bulunamadı",
    "Loading folders …" : "Klasörler yükleniyor…",
    "No photos in here" : "Burada herhangi bir fotoğraf yok",
    "Taken on {date} at {time}" : "{date} tarihinde {time} saatinde çekilmiş",
    "This place does not have any photos or videos yet!" : "Bu yerde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to this place" : "Bu yere fotoğraflar ekle",
    "Cover photo for place {placeName}" : "{placeName} yerinin kapak görseli",
    "There is no place yet!" : "Henüz bir yer yok!",
    "Cover photo for shared album {albumName}." : "{albumName} paylaşılmış albümünün kapak görseli.",
    "Back to tags overview" : "Etiket özetine geri dön",
    "No photos with this tag yet" : "Henüz bu şekilde etiketlenmiş bir fotoğraf yok",
    "No tags yet" : "Henüz bir etiket yok",
    "Photos with tags will show up here" : "Etiketlenmiş fotoğraflar burada görüntülenir",
    "Popular tags" : "Sık kullanılan etiketler",
    "All tags" : "Tüm etiketler",
    "One of the source folders does not exist" : "Kaynak klasörlerden biri bulunamadı",
    "Add to album" : "Albüme ekle",
    "Delete selection" : "Seçilmişleri sil",
    "No photos or videos in here" : "Henüz bir fotoğraf ya da görüntü yok",
    "Unassigned faces" : "İlişkilendirilmemiş yüzler",
    "_%n photos_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "Failed to fetch collection." : "Derleme alınamadı",
    "Failed to fetch collections list." : "Derleme listesi alınamadı.",
    "Failed to fetch faces list." : "Yüzlerin listesi alınamadı.",
    "All your media" : "Tüm ortamlarınız",
    "Album {title}" : "{title} albümü",
    "Shared Albums" : "Paylaşılmış albümler",
    "Shared album {title}" : "{title} paylaşılmış albümü",
    "Public album {title}" : "{title} herkese açık albüm",
    "Tagged photos" : "Etiketlenmiş fotoğraflar",
    "Tagged photo {title}" : "{title} etiketlenmiş fotoğraf",
    "{title}'s face" : "{title} yüzü",
    "{startDate} to {endDate}" : "{startDate} - {endDate}",
    "Details" : "Ayrıntılar",
    "Failed to rename {oldName} to {faceName}." : "{oldName} adı {faceName} olarak değiştirilemedi.",
    "Failed to delete {faceName}." : "{faceName} silinemedi.",
    "Failed to delete {fileId}." : "{fileId} silinemedi.",
    "Failed to delete {fileName}." : "{fileName} silinemedi.",
    "Failed to set favorite state for {fileId}." : "{fileId} için sık kullanılan durumu ayarlanamadı.",
    "Failed to set favorite state for {fileName}." : "{fileName} için sık kullanılan durumu ayarlanamadı.",
    "Could not load photos folder" : "Fotoğraflar klasörü yüklenemedi",
    "One of the source folders does not exists" : "Kaynak klasörlerden biri bulunamadı",
    "Add" : "Ekle"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/tr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Herkese açık bağlantı",
    "Photos" : "Fotoğraflar",
    "On This Day" : "Şu günde",
    "Your memories under your control" : "Anılarınızın denetimi sizde",
    "All media" : "Tüm ortamlar",
    "Videos" : "Görüntüler",
    "Albums" : "Albümler",
    "Collaborative albums" : "İş birlikli albümler",
    "People" : "Kişiler",
    "Folders" : "Klasörler",
    "Favorites" : "Sık kullanılanlar",
    "On this day" : "Bugün",
    "Shared with you" : "Sizinle paylaşılanlar",
    "Tags" : "Etiketler",
    "Places" : "Yerler",
    "Map" : "Harita",
    "Photos settings" : "Fotoğraflar ayarları",
    "Mark selection as favorite" : "Seçilmişleri sık kullanılanlara ekle",
    "Add selection to favorites" : "Seçilmişleri sık kullanılanlara ekle",
    "Remove selection from favorites" : "Seçilmişleri sık kullanılanlardan çıkar",
    "This name is already in use." : "Bu ad zaten kullanılıyor.",
    "\"{char}\" is not allowed inside a filename." : "Dosya adlarında \"{char}\" kullanılamaz.",
    "Invalid filename." : "Dosya adı geçersiz.",
    "Name of the album" : "Albümün adı",
    "Location of the album" : "Albümün konumu",
    "Back" : "Geri",
    "Add collaborators" : "Katılımcı ekle",
    "Save" : "Kaydet",
    "Create album" : "Albüm ekle",
    "Add to Album" : "Albüme ekle",
    "Add selection to album {albumName}" : "Seçilmişleri {albumName} albümüne ekle",
    "Shared by" : "Paylaşan",
    "Create a new album." : "Yeni bir albüm ekler.",
    "Create new album" : "Yeni albüm ekle",
    "New album" : "Yeni albüm",
    "_%n item_::_%n photos and videos_" : ["%n öge","%n fotoğraf ve görüntü"],
    "Failed to fetch collaborators list." : "Katılımcıların listesi alınamadı.",
    "Failed to update album." : "Albüm güncellenemedi",
    "Add people or groups who can edit your album" : "Albümünüzü düzenleyebilecek kişi ya da grupları ekleyin",
    "Search people or groups" : "Kişi ya da grup arama",
    "No recommendations. Start typing." : "Herhangi bir öneri yok. Yazmaya başlayın.",
    "Copy the public link" : "Herkese açık bağlantıyı kopyala",
    "Public link copied!" : "Herkese açık bağlantı kopyalandı!",
    "Copy public link" : "Herkese açık bağlantıyı kopyala",
    "Delete the public link" : "Herkese açık bağlantıyı sil",
    "Create public link share" : "Herkese açık paylaşılan bağlantı oluştur",
    "Share via public link" : "Herkese açık bağlantı ile paylaş",
    "This collection does not exist" : "Derleme bulunamadı",
    "An error occurred" : "Bir sorun çıktı",
    "No picture for this day" : "Bu günde çekilmiş bir fotoğraf yok",
    "Picture taken on this day will show up here." : "Bu gün çekilmiş fotoğraflar burada görüntülenir.",
    "More photos from this day" : "Bu gün çekilmiş diğer fotoğraflar",
    "_%n photos_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ilişkilendirilmemiş fotoğraf","%n ilişkilendirilmemiş fotoğraf"],
    "Favorite" : "Sık kullanılanlara ekle",
    "Favorite image, open the full size \"{name}\" image" : "Görseli öne çıkar, \"{name}\" görselini tam boyutunda aç",
    "Open the full size \"{name}\" image" : "\"{name}\" görselini tam boyutunda aç",
    "Select image {imageName}" : "{imageName} görselini seç",
    "Open the \"{name}\" folder" : "\"{name}\" klasörünü aç",
    "Go back" : "Geri dön",
    "Select a custom date range" : "Bir özel tarih aralığı seçin",
    "Select a date range" : "Bir tarih aralığı seçin",
    "Date range" : "Tarih aralığı",
    "Select filters" : "Süzgeçleri seçin",
    "Dates" : "Tarihler",
    "Jump to specific date in list" : "Listede belirli bir tarihe git",
    "Jump to {date}" : "{date} tarihine git",
    "Add to {destination}" : "{destination} üzerine ekle",
    "The destination folder is owned by {owner}" : "Hedef klasörün sahibi {owner}",
    "There are no photos or videos yet!" : "Henüz bir fotoğraf ya da görüntü yok!",
    "_{years} year ago_::_{years} years ago_" : ["{years} yıl önce","{years} yıl önce"],
    "Squared photos view" : "Kare fotoğraf görünümü",
    "Delete source directory" : "Kaynak klasörü sil",
    "Pick folder" : "Klasör seçin",
    "Select a source folder for your media" : "Ortamlarınız için bir kaynak klasör seçin",
    "Media folders" : "Ortam klasörleri",
    "Choose the folders from where photos and videos are shown." : "Fotoğraf ve videoların görüntüleneceği klasörleri seçin.",
    "All folders" : "Tüm klasörler",
    "Add a Photos source for the timelines" : "Zaman akışları için bir fotoğraf kaynağı ekleyin",
    "Add folder" : "Klasör ekle",
    "Home" : "Giriş",
    "Select the default upload location for your media" : "Ortamlarınız için varsayılan yükleme konumunu seçin",
    "Upload folder" : "Yükleme klasörü",
    "General" : "Genel",
    "_%n photo_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "Unselect all" : "Tümünü bırak",
    "Add photos to this album" : "Bu albüme fotoğraflar ekle",
    "Manage collaborators for this album" : "Bu albümün katılımcılarını yönet",
    "Open actions menu" : "İşlemler menüsünü aç",
    "Edit album details" : "Albüm ayrıntılarını düzenle",
    "Download all files in album" : "Albümdeki tüm dosyaları indir",
    "Delete album" : "Albümü sil",
    "Download selected files" : "Seçilmiş dosyaları indir",
    "Remove selection from album" : "Seçilmişleri albümden kaldır",
    "This album does not have any photos or videos yet!" : "Bu albümde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to {albumName}" : "{albumName} albümüne fotoğraflar ekle",
    "Manage collaborators" : "Katılımcı yönetimi",
    "Save collaborators for this album." : "Bu albümün katılımcılarını kaydet.",
    "Cover photo for album {albumName}" : "{albumName} albümünün kapak görseli",
    "There is no album yet!" : "Henüz bir albüm yok!",
    "This person could not be found" : "Bu kişi bulunamadı",
    "Rename person" : "Kişiyi yeniden adlandır",
    "Merge with different person" : "Başka bir kişi ile birleştir",
    "Download selected photos" : "Seçilmiş fotoğrafları indir",
    "Remove from favorites" : "Sık kullanılanlardan çıkar",
    "Remove person" : "Kişiyi sil",
    "Name of this person" : "Bu kişinin adı",
    "Save." : "Kaydeder.",
    "Merge person" : "Kişiyi birleştir",
    "Move to different person" : "Farklı bir kişiye aktar",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Fotoğrafı başka bir kişiye aktar","Fotoğrafları başka bir kişiye aktar"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fotoğrafı kişiden kaldır","Fotoğrafları kişiden kaldır"],
    "This might take some time depending on the size of your photo library." : "Bu işlemin tamamlanması fotoğraf arşivinizin boyutuna bağlı olarak biraz zaman alabilir.",
    "Recognized people will show up here" : "Tanınan kişiler burada görüntülenir",
    "This folder does not exist" : "Bu klasör bulunamadı",
    "Loading folders…" : "Klasörler yükleniyor…",
    "No photos in here" : "Burada herhangi bir fotoğraf yok",
    "Taken on {date} at {time}" : "{date} tarihinde {time} saatinde çekilmiş",
    "This place does not have any photos or videos yet!" : "Bu yerde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to this place" : "Bu yere fotoğraflar ekle",
    "Cover photo for place {placeName}" : "{placeName} yerinin kapak görseli",
    "There is no place yet!" : "Henüz bir yer yok!",
    "Cover photo for shared album {albumName}" : "{albumName} paylaşılmış albümünün kapak görseli",
    "Back to tags overview" : "Etiket özetine geri dön",
    "No photos with this tag yet" : "Henüz bu şekilde etiketlenmiş bir fotoğraf yok",
    "No tags yet" : "Henüz bir etiket yok",
    "Photos with tags will show up here" : "Etiketlenmiş fotoğraflar burada görüntülenir",
    "Popular tags" : "Sık kullanılan etiketler",
    "All tags" : "Tüm etiketler",
    "Create new album from filters" : "Süzgeçlerden yeni albüm oluştur",
    "One of the source folders does not exist" : "Kaynak klasörlerden biri bulunamadı",
    "Add to album" : "Albüme ekle",
    "Delete selection" : "Seçilmişleri sil",
    "No photos or videos in here" : "Henüz bir fotoğraf ya da görüntü yok",
    "Unassigned faces" : "İlişkilendirilmemiş yüzler",
    "Failed to fetch collection." : "Derleme alınamadı",
    "Failed to fetch collections list." : "Derleme listesi alınamadı.",
    "Failed to fetch faces list." : "Yüzlerin listesi alınamadı.",
    "Error fetching files" : "Dosyalar alınırken sorun çıktı",
    "All your media" : "Tüm ortamlarınız",
    "Album {title}" : "{title} albümü",
    "Shared Albums" : "Paylaşılmış albümler",
    "Shared album {title}" : "{title} paylaşılmış albümü",
    "Public album {title}" : "{title} herkese açık albüm",
    "Tagged photos" : "Etiketlenmiş fotoğraflar",
    "Tagged photo {title}" : "{title} etiketlenmiş fotoğraf",
    "{title}'s face" : "{title} yüzü",
    "Last week" : "Önceki hafta",
    "Last Month" : "Önceki ay",
    "Custom…" : "Özel…",
    "{startDate} to {endDate}" : "{startDate} - {endDate}",
    "Details" : "Ayrıntılar",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "{fileBaseName}, {collectionFileName} derlemesine eklenemedi",
    "Failed to delete {fileBaseName}" : "{fileBaseName} silinemedi",
    "Failed to create {collectionFileName}" : "{collectionFileName} oluşturulamadı",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "{currentCollectionFileName} adı {newCollectionFileName} olarak değiştirilemedi",
    "Failed to update properties of {collectionFileName} with {properties}" : "{collectionFileName} özellikleri {properties} olarak güncellenemedi",
    "Delete collection" : "Derlemeyi sil",
    "Leave shared album" : "Paylaşılmış albümden ayrıl",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "{collectionName} derlemesini silmek istediğinize emin misiniz? Bu işlem geri alınamaz.",
    "Failed to delete {collectionFileName}" : "{collectionFileName} silinemedi",
    "Cancel" : "İptal",
    "Confirm" : "Onayla",
    "Failed to move {fileBaseName} to person {faceName}" : "{fileBaseName}, {faceName} kişisine taşınamadı",
    "Failed to remove {fileBaseName}" : "{fileBaseName} kaldırılamadı",
    "Failed to rename {oldName} to {faceName}" : "{oldName} adı {faceName} olarak değiştirilemedi",
    "Failed to delete {faceName}" : "{faceName} silinemedi",
    "Failed to delete {fileId}" : "{fileId} silinemedi",
    "Failed to delete {fileName}" : "{fileName} silinemedi",
    "Failed to set favorite state for {fileId}" : "{fileId} için sık kullanılan durumu ayarlanamadı",
    "Failed to set favorite state for {fileName}" : "{fileName} için sık kullanılan durumu ayarlanamadı",
    "Could not load photos folder" : "Fotoğraflar klasörü yüklenemedi",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
    "Back to {folder}" : "{folder} klasörüne geri dön",
    "Share this folder" : "Bu klasörü paylaş",
    "Enable squared photos view" : "Kare fotoğraf görünümü kullanılsın",
    "Choose default Photos upload and Albums location" : "Varsayılan Fotoğraflar yüklemesini ve Albümlerin konumu seçin",
    "Choose a different folder" : "Farklı bir klasör seçin",
    "View" : "Görüntüle",
    "Choose the folder where photos and albums are uploaded to." : "Fotoğraf ve albümlerin yükleneceği klasörü seçin.",
    "Loading folders …" : "Klasörler yükleniyor…",
    "Add" : "Ekle"
},
"nplurals=2; plural=(n > 1);");
